@@ -1,12 +1,15 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
 ## Telegram API - ~/lib/Net/API/Telegram/Generic.pm
-## Version v0.100.1
-## Copyright(c) 2019 Jacques Deguest
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Version v0.100.2
+## Copyright(c) 2020 Jacques Deguest
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/06/02
-## Modified 2020/05/21
+## Modified 2024/09/05
+## All rights reserved
 ## 
+## This program is free software; you can redistribute  it  and/or  modify  it
+## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package Net::API::Telegram::Generic;
 BEGIN
@@ -20,11 +23,10 @@ BEGIN
     use DateTime::TimeZone;
     use File::Temp;
     use File::Spec;
-    ## For the JSON::true and JSON::false
+    # For the JSON::true and JSON::false
     use JSON;
-    use Nice::Try;
 	use Net::API::Telegram::Number;
-	our( $VERSION ) = 'v0.100.1';
+	our( $VERSION ) = 'v0.100.2';
 };
 
 sub init
@@ -258,21 +260,23 @@ sub _instantiate_object
 	};
 	$h->{_dbh} = $self->{_dbh} if( $self->{_dbh} );
 	my $o;
-	try
+	local $@;
+    # https://stackoverflow.com/questions/32608504/how-to-check-if-perl-module-is-available#comment53081298_32608860
+    eval( "require $class;" ) unless( defined( *{"${class}::"} ) );
+    # print( STDERR __PACKAGE__, "::_instantiate_object(): Error while loading module $class? $@\n" );
+    # $self->message( 3, "Error while loading module $class? $@" );
+    return( $self->error( "Unable to load module $class: $@" ) ) if( $@ );
+	# try-catch
+	eval
 	{
-		## https://stackoverflow.com/questions/32608504/how-to-check-if-perl-module-is-available#comment53081298_32608860
-		eval( "require $class;" ) unless( defined( *{"${class}::"} ) );
-		# print( STDERR __PACKAGE__, "::_instantiate_object(): Error while loading module $class? $@\n" );
-		# $self->message( 3, "Error while loading module $class? $@" );
-		return( $self->error( "Unable to load module $class: $@" ) ) if( $@ );
 		$o = @_ ? $class->new( $h, @_ ) : $class->new( $h );
-		return( $self->pass_error( "Unable to instantiate an object of class $class: ", $class->error ) ) if( !defined( $o ) );
-	}
-	catch( $e ) 
+	};
+	if( $@ )
 	{
 		# print( STDERR __PACKAGE__, "::_instantiate_object() An error occured while loading module $class for name '$name': $e\n" );
-		return( $self->error({ code => 500, message => $e }) );
+		return( $self->error({ code => 500, message => $@ }) );
 	}
+    return( $self->pass_error( "Unable to instantiate an object of class $class: ", $class->error ) ) if( !defined( $o ) );
 	# $self->message( 3, "Returning newly generated object $o with structure: ", $self->dumper( $o ) );
 	return( $o );
 }
@@ -495,4 +499,3 @@ sub _set_get_object_variant
 1;
 
 __END__
-
